@@ -1,20 +1,9 @@
-/*************************************************************************
- *  Copyright (C) 2008, 2009 by Volker Lanz <vl@fidra.de>                *
- *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009-2010 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2014-2020 Andrius Štikonas <andrius@stikonas.eu>
+
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "gui/treelog.h"
 #include "gui/partitionmanagerwidget.h"
@@ -32,7 +21,6 @@
 #include <QTreeWidget>
 #include <QTreeWidgetItem>
 
-#include <KIconLoader>
 #include <KIO/CopyJob>
 #include <KJobUiDelegate>
 #include <KLocalizedString>
@@ -153,7 +141,7 @@ void TreeLog::onNewLogMessage(Log::Level logLevel, const QString& s)
     if (static_cast<int>(logLevel) >= Config::minLogLevel()) {
         QTreeWidgetItem* item = new QTreeWidgetItem();
 
-        item->setIcon(0, QIcon::fromTheme(icons[static_cast<int>(logLevel)]).pixmap(IconSize(KIconLoader::Small)));
+        item->setIcon(0, QIcon::fromTheme(icons[static_cast<int>(logLevel)]));
         item->setText(1, QDateTime::currentDateTime().toString(QStringLiteral("yyyy-MM-dd hh:mm:ss")));
         item->setText(2, s);
 
